﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class Bird : GenericEnemy
{
	public GameObject DivingBird;

	bool isDiving = false;
	List<Vector2> waypoints = new List<Vector2>();
	int currentWaypointIndex = 0;
	Vector2 previousVelocity;
	float stillTimer = 0f;
	float stillTimerDelay = 2000f;

	public override void Start()
	{
		// no base.Start here, because the bird has different idle

		// these are all the child gameobjects
		foreach (Transform waypoint in transform)
		{
			waypoints.Add (new Vector2(waypoint.position.x, waypoint.position.y));
			Destroy (waypoint.gameObject);
		}
	}

	public override void Update()
	{
		// no base.Update here, because the bird has different idle logic

		if (isDiving)
		{
			if (stillTimer < stillTimerDelay)
				stillTimer += Time.deltaTime * 1000f;
			else
			{
				stillTimer = 0;
				rigidbody2D.velocity = previousVelocity;
				isDiving = false;
			}

			return;
		}

		Vector2 currentWaypointPosition = new Vector2 (waypoints [currentWaypointIndex].x, waypoints [currentWaypointIndex].y);
		if (Vector2.Distance (CurrentPosition, currentWaypointPosition) < 0.1f)
		{
			currentWaypointIndex++;
			currentWaypointIndex = (currentWaypointIndex >= waypoints.Count) ? 0 : currentWaypointIndex;

			currentWaypointPosition = new Vector2 (waypoints [currentWaypointIndex].x, waypoints [currentWaypointIndex].y);
			float rotation = GameMath.RotationTo (CurrentPosition, currentWaypointPosition);

			rigidbody2D.velocity = new Vector2(Mathf.Cos (rotation), Mathf.Sin(rotation));
		}
	}

	void OnTriggerEnter2D(Collider2D collider)
	{
		if (collider.gameObject.tag == "Humanoid")
		{
			if (!isDiving)
			{
				if(!audio.isPlaying)
				{
					audio.Play();
				}

				isDiving = true;
				previousVelocity = rigidbody2D.velocity;
				rigidbody2D.velocity = Vector2.zero;

				GameObject divingBird = Instantiate(DivingBird) as GameObject;
				divingBird.transform.position = transform.position;
			}
		}
	}
}