﻿using UnityEngine;
using System.Collections;

public enum EnemyState
{
	Idle,
	Attacking
}

public enum EnemyType
{
	Wolf,
	BigEnem
}

public class GenericEnemy : MonoBehaviour
{
	public float AggroRange;
	public float IdleRange;
	public float MaxIdleDelay;
	public float Speed;

	protected EnemyState state = EnemyState.Idle;
	public EnemyType type;
	Vector2 startingPosition;

	Vector2 nextIdlePosition = Vector2.zero;
	float idleTimer = 0f, idleNextDelay = 0f;

	// dont forget to call this function on your Start method


	public virtual void Start()
	{
		idleNextDelay = Random.value * MaxIdleDelay;
		idleTimer = 0;

		startingPosition = CurrentPosition;
	}

	public Vector2 CurrentPosition
	{
		get { return new Vector2 (transform.position.x, transform.position.y); }
	}

	// get a random point within a circle
	void GetRandomIdlePosition()
	{
		Vector3 circlePos = GameObject.FindGameObjectWithTag ("Follower").GetComponent<WolfFollowHumanoid>().transform.position;
		Vector2 TwoDPos = new Vector2(circlePos.x, circlePos.y);
		nextIdlePosition = GameMath.RandomPointWithinCircle (IdleRange);
		if (!GameObject.FindGameObjectWithTag ("Follower").GetComponent<WolfFollowHumanoid> ().ShouldLoopWaypoints && GameObject.FindGameObjectWithTag ("Follower").GetComponent<WolfFollowHumanoid> ().ShouldWaypoints)
						nextIdlePosition += startingPosition + TwoDPos;
				else if (GameObject.FindGameObjectWithTag ("Follower").GetComponent<WolfFollowHumanoid> ().ShouldWaypoints)
						nextIdlePosition = TwoDPos;
				else
						nextIdlePosition += startingPosition;
	}

	// dont forget to call this method in your Update method
	public virtual void Update()
	{
		if (state == EnemyState.Idle)
		{
			if (nextIdlePosition != Vector2.zero)
			{
				float rotation = GameMath.RotationTo(CurrentPosition, nextIdlePosition);

				if(type == EnemyType.Wolf)
					transform.eulerAngles = new Vector3(0f, 0f, rotation * Mathf.Rad2Deg);

				rigidbody2D.velocity = new Vector2(Mathf.Cos (rotation) * Speed, Mathf.Sin (rotation) * Speed);

				if (Vector2.Distance (CurrentPosition, nextIdlePosition) < 0.5f)
				{
					nextIdlePosition = Vector2.zero;
					idleNextDelay = Random.value * MaxIdleDelay;
					idleTimer = 0f;
					rigidbody2D.velocity = Vector2.zero;

					if (type == EnemyType.BigEnem)
						GetComponent<Animator>().SetBool("IsWalking", false);
				}

				return;
			}

			if (idleTimer < idleNextDelay)
				idleTimer += (Time.deltaTime * 1000f); // convert from seconds to ms
			else
			{
				GetRandomIdlePosition();

				if (type == EnemyType.BigEnem)
					GetComponent<Animator>().SetBool("IsWalking", true);
			}
		}
	}
}