﻿using UnityEngine;
using System.Collections;

public class HumanoidController : MonoBehaviour {

	public Vector2 WaypointPosition;
	public GameObject Cursor;
	public GameObject CursorMarker;

	public int NumberOfCivilians;
	public GameObject HumanoidTemplate;

	Sprite[] royalSprites;
	Sprite guardSprite;
	Sprite pilotSprite;
	Sprite attendantSprite;
	Sprite chefSprite;
	Sprite[] civilianSprites;

	public CameraMove camMov;
	public Sprite GameOverTex;
	bool isGameOver;

	public BloodSplatter BloodTemplate;
	

	// Use this for initialization
	void Start () {
		//Screen.showCursor = false;

		// load sprites
		royalSprites = new Sprite[3];
		for (int i = 0; i < 3; i++)
			royalSprites[i] = Resources.Load<Sprite>("Images/humanoids/royal_" + i);

		guardSprite = Resources.Load<Sprite> ("Images/humanoids/guard");
		pilotSprite = Resources.Load<Sprite> ("Images/humanoids/pilot");
		attendantSprite = Resources.Load<Sprite> ("Images/humanoids/attendant");
		chefSprite = Resources.Load<Sprite> ("Images/humanoids/chef");

		civilianSprites = new Sprite[7];
		for (int i = 0; i < 7; i++)
			civilianSprites [i] = Resources.Load<Sprite> ("Images/humanoids/civilian_" + i);

		GameOverTex = Resources.Load<Sprite> ("Images/GameOver");
	
		// quit if there are already humanoids, meaning we just loaded a level
		Vector2 randomPos;
		GameObject[] foundHumanoids = GameObject.FindGameObjectsWithTag ("Humanoid");
		if (foundHumanoids.Length > 0)
		{
			for (int i = 0; i < foundHumanoids.Length; i++)
			{
				GameObject spawnPoint = GameObject.FindGameObjectWithTag("SpawnPoint");
				randomPos = GameMath.RandomPointWithinCircle(2f);
				foundHumanoids[i].transform.position = spawnPoint.transform.position + new Vector3(randomPos.x, randomPos.y, 0f);

				foundHumanoids[i].GetComponent<Humanoid>().MoveTowards(foundHumanoids[i].transform.position);
				foundHumanoids[i].GetComponent<Humanoid> ().IsActive = true;
			}

			return;
		}

		// create default humanoids group
		Humanoid humanoid;
		for (int i = 0; i < 3; i++)
		{
			humanoid = (Instantiate(HumanoidTemplate) as GameObject).GetComponent<Humanoid>();
			randomPos = GameMath.RandomPointWithinCircle(2f);
			humanoid.transform.position = GameObject.FindGameObjectWithTag("SpawnPoint").transform.position + new Vector3(randomPos.x, randomPos.y, 0f);
			humanoid.SetData (royalSprites[i], true);
		}

		for (int i = 0; i < 5; i++)
		{
			humanoid = (Instantiate (HumanoidTemplate) as GameObject).GetComponent<Humanoid> ();
			randomPos = GameMath.RandomPointWithinCircle(2f);
			humanoid.transform.position = GameObject.FindGameObjectWithTag("SpawnPoint").transform.position + new Vector3(randomPos.x, randomPos.y, 0f);
			humanoid.SetData (guardSprite, false);
		}

		for (int i = 0; i < 2; i++)
		{
			humanoid = (Instantiate (HumanoidTemplate) as GameObject).GetComponent<Humanoid> ();
			randomPos = GameMath.RandomPointWithinCircle(2f);
			humanoid.transform.position = GameObject.FindGameObjectWithTag("SpawnPoint").transform.position + new Vector3(randomPos.x, randomPos.y, 0f);
			humanoid.SetData (pilotSprite, false);
		}

		for (int i = 0; i < 4; i++)
		{
			humanoid = (Instantiate (HumanoidTemplate) as GameObject).GetComponent<Humanoid> ();
			randomPos = GameMath.RandomPointWithinCircle(2f);
			humanoid.transform.position = GameObject.FindGameObjectWithTag("SpawnPoint").transform.position + new Vector3(randomPos.x, randomPos.y, 0f);
			humanoid.SetData (attendantSprite, false);
		}

		humanoid = (Instantiate (HumanoidTemplate) as GameObject).GetComponent<Humanoid> ();
		randomPos = GameMath.RandomPointWithinCircle(2f);
		humanoid.transform.position = GameObject.FindGameObjectWithTag("SpawnPoint").transform.position + new Vector3(randomPos.x, randomPos.y, 0f);
		humanoid.SetData (chefSprite, false);

		for (int i = 0; i < NumberOfCivilians; i++)
			SpawnRandomCivilianHumanoid(GameObject.FindGameObjectWithTag("SpawnPoint").transform.position);
	}

	public Humanoid SpawnRandomCivilianHumanoid(Vector3 startPosition)
	{
		Vector2 randomPosition = GameMath.RandomPointWithinCircle(3f);

		Humanoid humanoid;
		humanoid = (Instantiate (HumanoidTemplate) as GameObject).GetComponent<Humanoid> ();
		humanoid.transform.position = startPosition + new Vector3 (randomPosition.x, randomPosition.y, 0f);
		humanoid.SetData (civilianSprites[Random.Range(0, civilianSprites.Length)], false);

		return humanoid;
	}
	
	// Update is called once per frame
	void Update () 
	{
		Vector3 cursorScreenPosition = Camera.main.ScreenToWorldPoint (Input.mousePosition);
		Cursor.transform.position = new Vector3(cursorScreenPosition.x, cursorScreenPosition.y, 0f);

		GameObject[] gameObjects = GameObject.FindGameObjectsWithTag ("Humanoid");
		Humanoid[] humanoids = new Humanoid[gameObjects.Length];
		
		for (int i = 0; i < gameObjects.Length; i++)
			humanoids [i] = gameObjects [i].GetComponent<Humanoid> ();

		if (Input.GetMouseButtonDown (0)) 
		{
			WaypointPosition = Camera.main.ScreenToWorldPoint (Input.mousePosition);
			camMov.SetWaypoint (WaypointPosition);
			CursorMarker.transform.position = Cursor.transform.position;

			foreach (Humanoid humanoid in humanoids) 
				humanoid.MoveTowards (WaypointPosition);
		}

		isGameOver = true;
		foreach (Humanoid humanoid in humanoids) 
		{
			if (humanoid.GetIsRoyal())
				isGameOver = false;
		}
	}

	void OnGUI()
	{
		if (isGameOver) 
		{
			//GUI.DrawTexture(new Rect(0,0, Screen.width,Screen.height), GameOverTex.texture);
			//GUI.Label(new Rect(Screen.width / 3,(Screen.height*2 / 3), (Screen.width*2 / 3),Screen.height),"Game Over!\nYour people survived " + (Application.loadedLevel + 1).ToString() + "levels.");
		}
	}
}